package sun.reflect.misc;

import java.lang.reflect.InvocationTargetException;
import java.security.AccessController;
import java.lang.reflect.Method;

class Trampoline
{
    Trampoline() {
    }
    
    private static void ensureInvocableMethod(Method method) throws InvocationTargetException {
        Class<Object> declaringClass = method.getDeclaringClass();
        if (declaringClass.equals(AccessController.class) || declaringClass.equals(Method.class) || declaringClass.getName().startsWith("java.lang.invoke.")) {
            throw new InvocationTargetException(new UnsupportedOperationException("invocation not supported"));
        }
        return;
    }
    
    private static Object invoke(Method method, Object obj, Object[] args) throws InvocationTargetException, IllegalAccessException {
        ensureInvocableMethod(method);
        return method.invoke(obj, args);
    }
    
    static {
        if (Trampoline.class.getClassLoader() == null) {
            throw new Error("Trampoline must not be defined by the bootstrap classloader");
        }
        return;
    }
}
